@@ -1,6 +1,7 @@
-from pydantic import BaseModel, Extra
 from typing import Optional
 
+from pydantic import Extra, BaseModel
+
 
 class Config(BaseModel, extra=Extra.ignore):
     qweather_apikey: Optional[str] = None
